<?php
if ( ! class_exists( 'IPScarcityPlus_Setting' )) {

    /**
     * Class for manage countdown setting
     */
    class IPScarcityPlus_Setting
    {
        /**
         * Take countdown id
         *
         * @var string
         */
        protected $_countdownId;
        
        /**
         * Take countdown setting
         *
         * @var array
         */
        protected $_settings;
        
        /**
         * Class construct
         *
         * @param int $countdownId
         * @return void
         */
        public function __construct( $countdownId )
        {
            $this->_countdownId = absint( $countdownId );
            $this->_prepare();
        }
        
        /**
         * Get all countdown setting
         *
         * @return string
         */
        public function getSettings()
        {
            return $this->_settings;
        }
        
        /**
         * Get countdown setting
         *
         * @param  string $key
         * @param  mixed  $default
         * @return string
         */
        public function getSetting( $key, $default = false, $allowEmpty = false )
        {
            $setting = $default;
            if ( $allowEmpty ) {
                if ( isset( $this->_settings[$key] ) ) {
                    $setting = $this->_settings[$key];
                }
            } else {
                if ( ! empty( $this->_settings[$key] ) ) {
                    $setting = $this->_settings[$key];
                }
            }
            return $setting;
        }
        
        /**
         * Get all countdown setting
         *
         * @param  array $data
         * @return boolean
         */
        public function setSettings( $data )
        {
            $data     = (array)$data;
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Get countdown setting
         *
         * @param  string $key
         * @param  string $value
         * @return boolean
         */
        public function setSetting( $key, $value )
        {
            $data = array(
                $key => $value
            );
            $settings = (array)$this->_settings;
            $settings = array_merge( $settings, $data );
            $this->_settings = $settings;
            return $this->_update( $settings );
        }
        
        /**
         * Reset countdown setting
         *
         * @return boolean
         */
        public function reset()
        {
            $data = array( 'ipscarcityplus' => 1 );
            return $this->_update( $data );
        }
        
        /**
         * Prepare class
         *
         * @return void
         */
        protected function _prepare()
        {
            $id = $this->_countdownId;
            if ( ! empty( $id )) {
                $metas = get_post_meta( $id, '_ip_countdown_settings' );
                $meta  = array_shift( $metas );
                $this->_settings = maybe_unserialize( $meta );
            }
        }
        
        /**
         * Update settings
         *
         * @param  array $settings
         * @return boolean
         */
        protected function _update( $settings )
        {
            $settings = (array)$settings;
            return update_post_meta( $this->_countdownId, '_ip_countdown_settings', $settings );
        }
    }

}
?>