<?php
/*
Plugin Name: WP Scarcity Plus
Plugin URI: 
Description: Plugin that works to create a timer/countdown popup in your post/page
Version: 1.0
Author: InstaPRoduct
Author URI: http://insta-product.com/
*/

/*  
    LICENSE: This source file to be part of a system developed by InstaPRoduct. 
    All copyrights use this file and the code in it owned by InstaPRoduct. 
    It is strictly forbidden to use, copy, modify or distribute this file and 
    the code in it without the permission of the developer.
*/

//Change this value for rebranding plugin
define( 'IPSCARCITYPLUS_TITLE', 'Scarcity Plus' );

require_once( plugin_dir_path( __FILE__ ) . "includes/setting.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/admin.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/ajax.php" );
require_once( plugin_dir_path( __FILE__ ) . "includes/factory.php" );

/**
 * Class for generate social content
 */
if ( ! class_exists( 'IPScarcityPlus' )) {

    class IPScarcityPlus
    {
        /**
         * Setup Plugin
         */
        public function setup()
        {
            //Register admin menu
            add_action( 'admin_menu', array( 'IPScarcityPlus', 'addAdminMenu' ) );
            
            //Add Admin style
            add_action( 'admin_print_styles', array( 'IPScarcityPlus', 'printAdminStyle' ), 1000 );
            add_action( 'admin_print_footer_scripts', array( 'IPScarcityPlus', 'printAdminScript' ), 1000 );

            //Ajax handler
            add_action( 'admin_init', array( 'IPScarcityPlus', 'doAjax' ) );
            
            // Add meta box option
            add_action( 'add_meta_boxes', array( 'IPScarcityPlus', 'addMetaBox' ) );
            add_action( 'save_post', array( 'IPScarcityPlus', 'savePagePopup' ) );

            //Front Factory
            add_action( 'wp', array( 'IPScarcityPlus', 'frontInit' ) );
            add_action( 'wp_footer', array( 'IPScarcityPlus', 'factory' ) );
            
            //Add front style
            add_action('wp_head', array( 'IPScarcityPlus', 'printStyle' ) );
            
            //Add js library
            if ( ! is_admin() ) {
                add_action( "wp_enqueue_scripts", array( 'IPScarcityPlus', 'libScript' ), 11 );
            }
            
            //Add front script
            add_action('wp_enqueue_scripts', array( 'IPScarcityPlus', 'printScript' ), 12 );
        }
        
        /**
         * Add administrator menu
         *
         * @return void
         */
        public function addAdminMenu()
        {
            
            add_menu_page( 
                IPSCARCITYPLUS_TITLE, 
                IPSCARCITYPLUS_TITLE, 
                9, 
                'wp-scarcityplus', 
                array( 'IPScarcityPlus', 'adminPage' ), 
                plugin_dir_url( __FILE__ ) . 'img/menu_icon.png'
            );
            add_submenu_page( 
                'wp-scarcityplus', 
                'All Countdown', 
                'All Countdown', 
                9, 
                'wp-scarcityplus',
                array( 'IPScarcityPlus', 'adminPage' )
            );
            add_submenu_page( 
                'wp-scarcityplus', 
                'Add New', 
                'Add New', 
                9, 
                'wp-scarcityplus-add', 
                array( 'IPScarcityPlus', 'adminAdd' )
            );
            add_submenu_page( 
                'wp-scarcityplus', 
                'Countdown Settings', 
                'Countdown Settings', 
                9, 
                'wp-scarcityplus-home', 
                array( 'IPScarcityPlus', 'adminHome' )
            );
        }
        
        /**
         * Processing ajax request
         *
         * @return void
         */
        public function doAjax()
        {
            $ajax = new IPScarcityPlus_Ajax();
            return $ajax->exec();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminPage()
        {
            $display = new IPScarcityPlus_Admin();
            if ( ! empty( $_GET['action'] ) && $_GET['action'] == 'edit' ) {
                $display->edit();
            } else {
                $display->index();
            }
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminAdd()
        {
            $display = new IPScarcityPlus_Admin();
            $display->manage();
        }
        
        /**
         * Content for administrator page
         *
         * @return void
         */
        public function adminHome()
        {
            $display = new IPScarcityPlus_Admin();
            $display->adminHome();
        }
        
        /**
         * Add administrator meta box
         *
         * @return void
         */
        public function addMetaBox()
        {
            $screens = array( 'post', 'page' );
            foreach ($screens as $screen) {
                add_meta_box(
                    'ip_box_countdown',
                    __( 'Wp Scarcity Plus' ),
                    array( 'IPScarcityPlus', 'metaBoxContent' ),
                    $screen,
                    'side'
                );
            }
        }
        
        /**
         * Content for administrator meta box
         *
         * @return void
         */
        public function metaBoxContent( $post )
        {
            $display = new IPScarcityPlus_Admin();
            $display->metaBox( $post );
        }
        
        /**
         * Save page/post countdown
         *
         * @return void
         */
        public function savePagePopup( $post_id )
        {
            if ( 'page' == $_POST['post_type'] ) {
                if ( ! current_user_can( 'edit_page', $post_id ) ) {
                    return;
                }
            } else {
                if ( ! current_user_can( 'edit_post', $post_id ) ) {
                    return;
                }
            }
            // Check if the user intended to change this value.
            if ( ! isset( $_POST['ip_select_countdown_nonce'] ) ) {
                return;
            }
            $post_ID = $_POST['post_ID'];
            $data    = array(
                'countdown_id' => sanitize_text_field( $_POST['ip_countdown_select'] ),
                'position'     => sanitize_text_field( $_POST['ip_countdown_position'] )
            );
            update_post_meta( $post_ID, '_ip_post_countdown', $data );
        }
        
        /**
         * Main method for create Pop Up
         *
         * @return void
         */
        public function factory()
        {
            global $ipsp_factory;
            if ( ! $ipsp_factory ) {
                $ipsp_factory = new IPScarcityPlus_Factory();
            }
            $ipsp_factory->create();
        }
        
        /**
         * Initialize countdown
         *
         * @return void
         */
        public function frontInit()
        {
            global $ipsp_factory;
            $ipsp_factory = new IPScarcityPlus_Factory();
            $ipsp_factory->init();
        }

        /**
         * Print admin style
         *
         * @return void
         */
        public function printAdminStyle()
        {
            $href1 = plugin_dir_url( __FILE__ ) . 'css/admin.css';
            $href2 = plugin_dir_url( __FILE__ ) . 'js/counter/jquery.counter.css';
            $href3 = plugin_dir_url( __FILE__ ) . 'js/modalBox/jquery.modalbox.css';
            $href4 = plugin_dir_url( __FILE__ ) . 'css/style.css';
            echo '<link media="all" type="text/css" href="' . $href1 . '" rel="stylesheet">';
            echo '<link media="all" type="text/css" href="' . $href2 . '" rel="stylesheet">';
            echo '<link media="all" type="text/css" href="' . $href3 . '" rel="stylesheet">';
            echo '<link media="all" type="text/css" href="' . $href4 . '" rel="stylesheet">';
        }

        /**
         * Print Admin Script
         *
         * @return void
         */
        public function printAdminScript()
        {
            $src1 = plugin_dir_url( __FILE__ ) . 'js/admin.js';
            $src2 = plugin_dir_url( __FILE__ ) . 'js/modalBox/jquery.modalbox.js';
            $src3 = plugin_dir_url( __FILE__ ) . 'js/counter/jquery.counter.min.js';
            echo '<script type="text/javascript" src="' . $src1 . '"></script>';
            echo '<script type="text/javascript" src="' . $src2 . '"></script>';
            echo '<script type="text/javascript" src="' . $src3 . '"></script>';
        }

        /**
         * Print style
         *
         * @return void
         */
        public function printStyle()
        {
        ?>
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>css/style.css" rel="stylesheet">
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>js/counter/jquery.counter.css" rel="stylesheet">
            <link media="all" type="text/css" href="<?php echo plugin_dir_url( __FILE__ ) ?>js/modalBox/jquery.modalbox.css" rel="stylesheet">
        <?php
        }

        /**
         * Print script
         *
         * @return void
         */
        public function printScript()
        {
            wp_deregister_script('counter-script');
            wp_deregister_script('ip-modal-box');
            wp_enqueue_script(
                'ip-modal-box',
                plugin_dir_url( __FILE__ ) . 'js/modalBox/jquery.modalbox.js'
            );
            wp_enqueue_script(
                'counter-script',
                plugin_dir_url( __FILE__ ) . 'js/counter/jquery.counter.min.js'
            );
            wp_enqueue_script(
                'ipsp-front-script',
                plugin_dir_url( __FILE__ ) . 'js/script.js',
                array( 'jquery' ),
                1,
                true
            );
        }

        /**
         * Lib script
         *
         * @return void
         */
        public function libScript()
        {
            wp_deregister_script('jquery');
            wp_register_script('jquery', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jquery/1.7.1/jquery.min.js", false, null);
            wp_enqueue_script('jquery');
            
            wp_deregister_script('jquery-ui');
            wp_register_script('jquery-ui', "http" . ($_SERVER['SERVER_PORT'] == 443 ? "s" : "") . "://ajax.googleapis.com/ajax/libs/jqueryui/1.10.3/jquery-ui.min.js", false, null);
            wp_enqueue_script('jquery-ui');
        }
    }

}
//Run plugin
IPScarcityPlus::setup();
?>